@@ -5,13 +5,11 @@ This module does not contain docstrings for the wrapped code, check Apple's
 documentation for details on how to use these functions and classes.
 """
 
-import objc
 import sys
+
 import Foundation
-
-from SystemExtensions import _metadata
-from SystemExtensions import _SystemExtensions
-
+import objc
+from SystemExtensions import _metadata, _SystemExtensions
 
 sys.modules["SystemExtensions"] = mod = objc.ObjCLazyModule(
     "SystemExtensions",
@@ -25,9 +23,8 @@ sys.modules["SystemExtensions"] = mod = objc.ObjCLazyModule(
         "__path__": __path__,
         "__loader__": globals().get("__loader__", None),
     },
-    (Foundation,),
+    (_SystemExtensions, Foundation),
 )
 
-import sys
 
 del sys.modules["SystemExtensions._metadata"]
